From 6ede355dbb97967a91c01d912494cbd7abbfa9fc Mon Sep 17 00:00:00 2001
From: Jason Hiser <jdhiser@gmail.com>
Date: Sat, 16 Feb 2019 04:25:08 -0500
Subject: [PATCH] changed path to testing dir to not conflict with other types
 of nightly tests

Former-commit-id: b4042aeada4fdaecdd0e7bd0b5724d53d41bef3d
---
 cicd_tests/do-build.sh  | 10 +++++-----
 cicd_tests/do-clean.sh  |  2 +-
 cicd_tests/elfdep.sh    |  2 +-
 cicd_tests/test_fib.sh  |  2 +-
 cicd_tests/test_foo.sh  |  2 +-
 cicd_tests/xform-cat.sh |  2 +-
 cicd_tests/xform-ls.sh  |  2 +-
 7 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/cicd_tests/do-clean.sh b/cicd_tests/do-clean.sh
index 95dc3b04b..940af5a55 100755
--- a/cicd_tests/do-clean.sh
+++ b/cicd_tests/do-clean.sh
@@ -14,7 +14,7 @@ main()
 
 
 	if [[ $CICD_NIGHTLY == 1 ]] ; then
-		rm -rf $CICD_MODULE_WORK_DIR/peasoup_umbrella
+		rm -rf $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 	fi
 
 }
diff --git a/cicd_tests/elfdep.sh b/cicd_tests/elfdep.sh
index 9046a1eac..81c3f7840 100755
--- a/cicd_tests/elfdep.sh
+++ b/cicd_tests/elfdep.sh
@@ -2,7 +2,7 @@
 set -e
 set -x
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 source set_env_vars
 
 cd $SECURITY_TRANSFORMS_HOME/libIRDB-elfdep/test/
diff --git a/cicd_tests/test_fib.sh b/cicd_tests/test_fib.sh
index 636ae021e..f2e487cd7 100755
--- a/cicd_tests/test_fib.sh
+++ b/cicd_tests/test_fib.sh
@@ -3,7 +3,7 @@
 set -e
 trap clean EXIT
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 source set_env_vars
 cd ./irdb-libs/tools/selective_cfi/tests/cicd_tests/fib_src
 
diff --git a/cicd_tests/test_foo.sh b/cicd_tests/test_foo.sh
index d9a50a838..b18767c16 100755
--- a/cicd_tests/test_foo.sh
+++ b/cicd_tests/test_foo.sh
@@ -3,7 +3,7 @@
 set -e
 trap clean EXIT
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 source set_env_vars
 cd ./security_transforms/tools/selective_cfi/tests/cicd_tests/foo_src
 
diff --git a/cicd_tests/xform-cat.sh b/cicd_tests/xform-cat.sh
index b969ed97c..4ee04a86d 100755
--- a/cicd_tests/xform-cat.sh
+++ b/cicd_tests/xform-cat.sh
@@ -1,4 +1,4 @@
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 
 set -e
 set -x
diff --git a/cicd_tests/xform-ls.sh b/cicd_tests/xform-ls.sh
index b9741e234..f31df7b40 100755
--- a/cicd_tests/xform-ls.sh
+++ b/cicd_tests/xform-ls.sh
@@ -2,7 +2,7 @@
 set -e
 set -x
 
-cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 source set_env_vars
 cd /tmp
 rm -rf ls.rida ped_ls
diff --git a/cicd_tests/do-build.sh b/cicd_tests/do-build.sh
index 37e5fc06f..b60636f4c 100755
--- a/cicd_tests/do-build.sh
+++ b/cicd_tests/do-build.sh
@@ -17,15 +17,15 @@ main()
 
 	local orig_dir=$(pwd)
 
-	# puts peasoup_umbrella (and all submodules) in CICD_MODULE_WORK_DIR
-	cicd_setup_module_dependency allnp/peasoup_umbrella.git
+	# puts irdblibs_umbrella (and all submodules) in CICD_MODULE_WORK_DIR
+	cicd_setup_module_dependency allnp/irdblibs_umbrella.git
 
 
-	# puts the version of irdb-libs to test in peasoup_umbrella/irdb-libs
-	cicd_put_module_in_tree peasoup_umbrella/irdb-libs
+	# puts the version of irdb-libs to test in irdblibs_umbrella/irdb-libs
+	cicd_put_module_in_tree irdblibs_umbrella/irdb-libs
 
 	# Build/run $PSZ, test result
-	cd $CICD_MODULE_WORK_DIR/peasoup_umbrella
+	cd $CICD_MODULE_WORK_DIR/irdblibs_umbrella
 	source set_env_vars
 	sudo ./get-peasoup-packages.sh all
 
-- 
GitLab